==> haskell-doctest-driver-gen-0.3.0.8-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-driver-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-driver-gen
version:              0.3.0.8
visibility:           public
id:                   doctest-driver-gen-0.3.0.8-1QEoYb0ncqF8ZKbmAWC0M8
key:                  doctest-driver-gen-0.3.0.8-1QEoYb0ncqF8ZKbmAWC0M8
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2023
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  413ac798462ac9ef23f0a868e2c53f9e
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-driver-gen
hs-libraries:         HSdoctest-driver-gen-0.3.0.8-1QEoYb0ncqF8ZKbmAWC0M8
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-driver-gen-0.3.0.8-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-driver-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-driver-gen
version:              0.3.0.8
visibility:           public
id:                   doctest-driver-gen-0.3.0.8-CTiJCEY4xox5Z2rDmGLvSC
key:                  doctest-driver-gen-0.3.0.8-CTiJCEY4xox5Z2rDmGLvSC
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2023
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  91d95c6110fd5a84fe73e69bf569855a
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-driver-gen-0.3.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-driver-gen
hs-libraries:         HSdoctest-driver-gen-0.3.0.8-CTiJCEY4xox5Z2rDmGLvSC
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
